<?xml version="1.0" encoding="utf-8"?>

<!-- Original traditional Chinese translation done by ZX-WT (https://github.com/ZX-WT) -->

<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>ColorParameter</name>
    <message>
        <location filename="../src/FilterParameters/ColorParameter.cpp" line="168"/>
        <source>Select color</source>
        <translation>選取顏色</translation>
    </message>
</context>
<context>
    <name>DialogSettings</name>
    <message>
        <location filename="../ui/dialogsettings.ui" line="14"/>
        <source>Dialog</source>
        <translation>對話框</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="221"/>
        <source>Internet updates</source>
        <translation>網絡更新</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="230"/>
        <source>Update now</source>
        <translation>立刻更新</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="30"/>
        <source>Layout</source>
        <translation>佈局</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="24"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="64"/>
        <source>Preview on the &amp;left</source>
        <translation>在左邊預覽 (&amp;L)</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="94"/>
        <source>Pre&amp;view on right side</source>
        <translation>在右邊預覽 (&amp;V)</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="113"/>
        <source>Theme</source>
        <translation>主題</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="119"/>
        <source>&amp;Default</source>
        <translation>預設 (&amp;D)</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="126"/>
        <source>Dar&amp;k</source>
        <translation>暗色 (&amp;K)</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="139"/>
        <source>&lt;i&gt;(Restart needed)&lt;/I&gt;</source>
        <translation>&lt;i&gt;(需要重開)&lt;/I&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="149"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="179"/>
        <source>Always enable preview zooming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="186"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-style:italic;&quot;&gt;(Warning: preview may be inaccurate&lt;br/&gt;if checked.)&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="215"/>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="253"/>
        <location filename="../src/DialogSettings.cpp" line="84"/>
        <source>Output messages</source>
        <translation>輸出信息</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="196"/>
        <source>Dialogs</source>
        <translation>對話</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="202"/>
        <source>Use native color dialog</source>
        <translation>改用原生色彩對話框</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="163"/>
        <source>Preview</source>
        <translation>預覽</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="169"/>
        <source>Timeout (seconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="36"/>
        <source>Show institution logos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="262"/>
        <source>Notify when scheduled update fails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="304"/>
        <source>&amp;Ok</source>
        <translation>確定 (&amp;O)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="64"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="70"/>
        <source>Never</source>
        <translation>永不</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="71"/>
        <source>Daily</source>
        <translation>​每天</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="72"/>
        <source>Weekly</source>
        <translation>每週</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="73"/>
        <source>Every 2 weeks</source>
        <translation>每兩週</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="74"/>
        <source>Monthly</source>
        <translation>每月</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="76"/>
        <source>At launch (debug)</source>
        <translation>啟動時 (debug)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="85"/>
        <source>Quiet (default)</source>
        <translation>簡單 (預設)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="86"/>
        <source>Verbose (console)</source>
        <translation>繁複 (控制台)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="87"/>
        <source>Verbose (log file)</source>
        <translation>繁複 (log 檔案)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="88"/>
        <source>Very verbose (console)</source>
        <translation>超繁複 (控制台)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="89"/>
        <source>Very verbose (log file)</source>
        <translation>超繁複 (log 檔案)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="90"/>
        <source>Debug (console)</source>
        <translation>Debug (控制台)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="91"/>
        <source>Debug (log file)</source>
        <translation>Debug (log 檔案)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="107"/>
        <source>Check to use Native/OS color dialog, uncheck to use Qt&apos;s</source>
        <translation>勾選以使用原生色彩對話框，不選以使用Qt</translation>
    </message>
</context>
<context>
    <name>FileParameter</name>
    <message>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="149"/>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="152"/>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="155"/>
        <source>Select a file</source>
        <translation>選取檔案</translation>
    </message>
</context>
<context>
    <name>FilterParametersWidget</name>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="39"/>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="172"/>
        <source>&lt;i&gt;Select a filter&lt;/i&gt;</source>
        <translation>&lt;i&gt;選擇濾鏡&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="139"/>
        <source>&lt;i&gt;No parameters&lt;/i&gt;</source>
        <translation>&lt;i&gt;沒有參數&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="144"/>
        <source>Error parsing filter parameters

</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FiltersPresenter</name>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="339"/>
        <source>Unknown filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="427"/>
        <source>Cannot find this fave&apos;s original filter
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FiltersView</name>
    <message>
        <location filename="../ui/filtersview.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="65"/>
        <source>Rename fave</source>
        <translation>重新命名最愛列</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="67"/>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="344"/>
        <source>Remove fave</source>
        <translation>從最愛移除</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="69"/>
        <source>Clone fave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="73"/>
        <source>Add fave</source>
        <translation>加到最愛列</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="345"/>
        <source>Do you really want to remove the following fave?

%1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FolderParameter</name>
    <message>
        <location filename="../src/FilterParameters/FolderParameter.cpp" line="127"/>
        <source>Select a folder</source>
        <translation>選取資料夾</translation>
    </message>
</context>
<context>
    <name>HeadlessProgressDialog</name>
    <message>
        <location filename="../ui/headlessprogressdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>對話</translation>
    </message>
    <message>
        <location filename="../ui/headlessprogressdialog.ui" line="68"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>InOutPanel</name>
    <message>
        <location filename="../ui/inoutpanel.ui" line="40"/>
        <location filename="../src/Widgets/InOutPanel.cpp" line="271"/>
        <source>Input / Output</source>
        <translation>輸入／輸出</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="47"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="102"/>
        <location filename="../src/Widgets/InOutPanel.cpp" line="72"/>
        <source>Input layers</source>
        <translation>輸入圖層</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="138"/>
        <location filename="../src/Widgets/InOutPanel.cpp" line="95"/>
        <source>Output mode</source>
        <translation>輸出模式</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="125"/>
        <location filename="../src/Widgets/InOutPanel.cpp" line="111"/>
        <source>Preview mode</source>
        <translation>預覽模式</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="273"/>
        <source>Input / Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="273"/>
        <source>Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="275"/>
        <source>Output / Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="275"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageSelectionWidget</name>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="38"/>
        <source>&lt;i&gt;(Restart needed)&lt;/i&gt;</source>
        <translation>&lt;i&gt;(需要重開)&lt;/I&gt;</translation>
    </message>
    <message>
        <location filename="../src/Widgets/LanguageSelectionWidget.cpp" line="48"/>
        <source>System default (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainwindow.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="161"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Download filter definitions from remote sources&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;從遠端下載濾鏡定義&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="164"/>
        <source>Internet</source>
        <translation>互聯網</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="233"/>
        <location filename="../ui/mainwindow.ui" line="240"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="386"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enable/disable preview&lt;br/&gt;(Ctrl+P)&lt;br/&gt;(right click on preview image for instant swapping)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="389"/>
        <source>Preview</source>
        <translation>預覽</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="480"/>
        <source>Settings...</source>
        <translation>設定...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="496"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="509"/>
        <source>&amp;Cancel</source>
        <translation>取消 (&amp;C)</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="522"/>
        <source>&amp;Fullscreen</source>
        <translation>全螢幕 (&amp;F)</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="535"/>
        <source>&amp;Apply</source>
        <translation>應用 (&amp;A)</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="548"/>
        <source>&amp;OK</source>
        <translation>確定 (&amp;O)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="102"/>
        <source>Add fave</source>
        <translation>加到最愛列</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="104"/>
        <source>Reset parameters to default values</source>
        <translation>重設參數成預設值</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="110"/>
        <source>Copy G&apos;MIC command to clipboard</source>
        <translation>将G&apos;MIC命令复制到剪贴板</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="166"/>
        <source>Update filters</source>
        <translation>更新濾鏡</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="113"/>
        <source>Rename fave</source>
        <translation>重新命名最愛列</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="115"/>
        <source>Remove fave</source>
        <translation>從最愛移除</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="119"/>
        <source>Expand/Collapse all</source>
        <translation>全部展開／折疊</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="121"/>
        <source>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandy University (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="128"/>
        <source>Selection mode</source>
        <translation>選取模式</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="329"/>
        <source>Update completed</source>
        <translation>更新完成</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="329"/>
        <location filename="../src/MainWindow.cpp" line="331"/>
        <location filename="../src/MainWindow.cpp" line="385"/>
        <source>Filter definitions have been updated.</source>
        <translation>濾鏡定義已更新。</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="334"/>
        <source>No download was needed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="381"/>
        <source>Filters update could not be achieved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="503"/>
        <source>The update could not be achieved&lt;br&gt;because of the following errors:&lt;br&gt;</source>
        <translation>這次更新由於以下错誤&lt;br/&gt;未能完成:&lt;br/&gt;</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="509"/>
        <source>Update error</source>
        <translation>更新出錯</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="711"/>
        <source>Error</source>
        <translation>出錯</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="807"/>
        <source>Waiting for cancelled jobs...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1169"/>
        <source>Import faves</source>
        <translation>導入最愛列</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1169"/>
        <source>Do you want to import faves from file below?&lt;br/&gt;%1</source>
        <translation>你要從以下文件導入最愛列嗎？&lt;br/&gt;%1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1172"/>
        <source>Don&apos;t ask again</source>
        <translation>不要再問</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1284"/>
        <source>Confirmation</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1284"/>
        <source>A gmic command is running.&lt;br&gt;Do you really want to close the plugin?</source>
        <translation>gmic 命令正在運行。&lt;br&gt;你確定要關閉插件嗎?</translation>
    </message>
</context>
<context>
    <name>MultilineTextParameterWidget</name>
    <message>
        <location filename="../ui/multilinetextparameterwidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/multilinetextparameterwidget.ui" line="29"/>
        <source>Update</source>
        <translation>更新</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/MultilineTextParameterWidget.cpp" line="38"/>
        <source>Ctrl+Return</source>
        <translation>Ctrl+Return</translation>
    </message>
</context>
<context>
    <name>ProgressInfoWidget</name>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="48"/>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="49"/>
        <source>Abort</source>
        <translation>中斷</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="55"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="46"/>
        <source>G&apos;MIC-Qt Plug-in progression</source>
        <translation>G&apos;MIC-Qt 插件正在處理</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="147"/>
        <source>Updating filters...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="202"/>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="215"/>
        <source>[Processing %1 | %2]</source>
        <translation>[處理中 %1 | %2]</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="217"/>
        <source>[Processing %1]</source>
        <translation>[處理中 %1]</translation>
    </message>
</context>
<context>
    <name>ProgressInfoWindow</name>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished">MainWindow</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="30"/>
        <location filename="../ui/progressinfowindow.ui" line="50"/>
        <source>TextLabel</source>
        <translation type="unfinished">TextLabel</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="72"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="138"/>
        <source>%1 seconds</source>
        <translation>%1 秒</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="148"/>
        <source>[Processing %1 | %2]</source>
        <translation>[處理中 %1 | %2]</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="150"/>
        <source>[Processing %1]</source>
        <translation>[處理中 %1]</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="88"/>
        <source>Visible</source>
        <translation>可見</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="86"/>
        <source>Available filters (%1)</source>
        <translation>可用的濾鏡(%1)</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="68"/>
        <source>Select an image to open...</source>
        <translation>開啟圖片...</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="68"/>
        <source>PNG &amp; JPG files (*.png *.jpeg *.jpg *.PNG *.JPEG *.JPG)</source>
        <translation>PNG &amp; JPG 檔案 (*.png *.jpeg *.jpg *.PNG *.JPEG *.JPG)</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="74"/>
        <source>Error</source>
        <translation>出錯</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="74"/>
        <source>Could not open file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="78"/>
        <source>Default image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchFieldWidget</name>
    <message>
        <location filename="../ui/SearchFieldWidget.ui" line="20"/>
        <source>Frame</source>
        <translation>Frame</translation>
    </message>
    <message>
        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="76"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="77"/>
        <source>Search in filters list (%1)</source>
        <translation>篩選搜尋(%1)</translation>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <location filename="../src/Updater.cpp" line="195"/>
        <source>Error downloading %1 (empty file?)</source>
        <translation>下載出錯 %1 (空白檔案?)</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="204"/>
        <source>Could not read/decompress %1</source>
        <translation>不能讀取／解壓縮 %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="210"/>
        <source>Error creating file %1</source>
        <translation>建立檔案時出錯 %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="214"/>
        <source>Error writing file %1</source>
        <translation>寫入檔案出錯 %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="231"/>
        <source>Error downloading %1&lt;br/&gt;Error %2: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="264"/>
        <source>Download timeout: %1</source>
        <translation>下載超時：%1</translation>
    </message>
</context>
<context>
    <name>ZoomLevelSelector</name>
    <message>
        <location filename="../ui/zoomlevelselector.ui" line="20"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="51"/>
        <source>Zoom in</source>
        <translation type="unfinished">放大</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="52"/>
        <source>Zoom out</source>
        <translation type="unfinished">縮小</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="53"/>
        <source>Reset zoom</source>
        <translation type="unfinished">重設縮放比例</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="153"/>
        <source>Warning: Preview may be inaccurate (zoom factor has been modified)</source>
        <translation type="unfinished">警告：預覽可能不準確 (縮放比例已修改)</translation>
    </message>
</context>
</TS>
